async fn verify_block<TContext: Pacer>(
context: TContext,
epoch: Epoch,
epoch_strategy: &FixedEpocher,
engine: ConsensusEngineHandle<TempoPayloadTypes>,
block: &Block,
parent_digest: Digest,
scheme_provider: &SchemeProvider,
) -> Result<Option<Duration>>Expand description
Verifies block given its parent against the execution layer.
Returns EL validation duration when validation reached the execution layer
and succeeded, or None if the block is invalid. Returns an error if
validation was not possible, for example if communication with the execution
layer failed.
Reason the reason for why a block was not valid is communicated as a tracing event.